==> integrit-1.00.07-beta.tar.gz: integrit-1.00/cdb_seq.c <==
/*
integrit - file integrity verification system
Copyright (C) 2000 Ed Cashin

You can redistribute this program and/or modify it under the terms of
the Artistic License as published by the Open Source Initiative,
currently at the following URL:

    http://www.opensource.org/licenses/artistic-license.html

THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

*/
#include	<config.h>
#include	<stdlib.h>
#include	<unistd.h>
#include	<errno.h>
#include	"cdb.h"
#include	"buffer.h"
#include	"cdb_make.h"
#include	"uint32.h"
#include	"elcerror.h"
#include	"cdb_seq.h"

#define	CDB_HEADER_SIZE	(2048)

int cdb_seq_start(cdb_seq *c)
{
    int		err;
    int		fd	 = c->fd;

    if ( (err = lseek(fd, 0, SEEK_SET)) == -1)
      return -1;
    if ( (err = read(fd, &c->eod, sizeof(c->eod))) == -1)
      return -1;
    else if (err < sizeof(c->eod)) {
      errno	 = EIO;		/* ENODATA not on FreeBSD */
      return -1;
    }

    return lseek(fd, CDB_HEADER_SIZE, SEEK_SET);
}

int cdb_seq_eod(cdb_seq *c)
{
    int		pos;

    if ( (pos = lseek(c->fd, 0, SEEK_CUR)) == -1)
      return -1;

    return pos >= c->eod;
}

int cdb_seq_sizes(cdb_seq *c, size_t *klen, size_t *vlen)
{
    int		err;

    if ( (err = read(c->fd, klen, sizeof(*klen))) == -1)
      return -1;
    else if (err == 0)
      return 1;			/* no more */

    if ( (err = read(c->fd, vlen, sizeof(*vlen))) == -1)
      return -1;
    else if (err == 0)
      return 1;			/* no more */

    return 0;
}

int cdb_seq_get(cdb_seq *c, void *key, size_t klen, void *data, size_t dlen)
{
    int		err;

    if ( (err = read(c->fd, key, klen)) == -1)
      return -1;
    else if (err == 0)
      return 1;			/* no more */

    if ( (err = read(c->fd, data, dlen)) == -1)
      return -1;
    else if (err == 0)
      return 1;			/* no more */

    return 0;
}

int cdb_seq_getkey(cdb_seq *c, void *key, size_t klen, size_t dlen)
{
    int		err;

    if ( (err = read(c->fd, key, klen)) == -1)
      return -1;
    else if (err == 0)
      return 1;			/* no more */

    if (lseek(c->fd, dlen, SEEK_CUR) == -1)
      return -1;

    return 0;
}

==> integrit-1.03.05-beta.tar.gz: integrit-1.03/cdb_seq.c <==
/*
integrit - file integrity verification system
Copyright (C) 2000 Ed Cashin

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/
#include	<config.h>
#include	<stdlib.h>
#include	<unistd.h>
#include	<errno.h>
#include	"cdb.h"
#include	"buffer.h"
#include	"cdb_make.h"
#include	"uint32.h"
#include	"elcerror.h"
#include	"cdb_seq.h"

#define	CDB_HEADER_SIZE	(2048)

int cdb_seq_start(cdb_seq *c)
{
    int		err;
    int		fd	 = c->fd;

    if ( (err = lseek(fd, 0, SEEK_SET)) == -1)
      return -1;
    if ( (err = read(fd, &c->eod, sizeof(c->eod))) == -1)
      return -1;
    else if (err < sizeof(c->eod)) {
      errno	 = EIO;		/* ENODATA not on FreeBSD */
      return -1;
    }

    return lseek(fd, CDB_HEADER_SIZE, SEEK_SET);
}

int cdb_seq_eod(cdb_seq *c)
{
    int		pos;

    if ( (pos = lseek(c->fd, 0, SEEK_CUR)) == -1)
      return -1;

    return pos >= c->eod;
}

int cdb_seq_sizes(cdb_seq *c, size_t *klen, size_t *vlen)
{
    int		err;

    if ( (err = read(c->fd, klen, sizeof(*klen))) == -1)
      return -1;
    else if (err == 0)
      return 1;			/* no more */

    if ( (err = read(c->fd, vlen, sizeof(*vlen))) == -1)
      return -1;
    else if (err == 0)
      return 1;			/* no more */

    return 0;
}

int cdb_seq_get(cdb_seq *c, void *key, size_t klen, void *data, size_t dlen)
{
    int		err;

    if ( (err = read(c->fd, key, klen)) == -1)
      return -1;
    else if (err == 0)
      return 1;			/* no more */

    if ( (err = read(c->fd, data, dlen)) == -1)
      return -1;
    else if (err == 0)
      return 1;			/* no more */

    return 0;
}

int cdb_seq_getkey(cdb_seq *c, void *key, size_t klen, size_t dlen)
{
    int		err;

    if ( (err = read(c->fd, key, klen)) == -1)
      return -1;
    else if (err == 0)
      return 1;			/* no more */

    if (lseek(c->fd, dlen, SEEK_CUR) == -1)
      return -1;

    return 0;
}
